@@ -1,12 +1,10 @@
 from typing import Any, Dict
 
-from python3_capsolver.core.enum import CaptchaTypeEnm
-from python3_capsolver.core.serializer import TaskSer
-
+from .enum import CaptchaTypeEnm
 from .const import REQUEST_URL
-from .serializer import RequestCreateTaskSer, RequestGetTaskResultSer
+from .serializer import TaskSer, RequestCreateTaskSer, RequestGetTaskResultSer
 from .context_instr import AIOContextManager, SIOContextManager
-from .captcha_instrument import CaptchaInstrument
+from .captcha_instrument import CaptchaInstrumentBase
 from .aio_captcha_instrument import AIOCaptchaInstrument
 from .sio_captcha_instrument import SIOCaptchaInstrument
 
@@ -38,7 +36,7 @@ class CaptchaParams(SIOContextManager, AIOContextManager):
         # prepare `get task result` payload
         self.get_result_params = RequestGetTaskResultSer(clientKey=api_key)
         self.request_url = request_url
-        self._captcha_handling_instrument = CaptchaInstrument()
+        self._captcha_handling_instrument = CaptchaInstrumentBase()
         self.sleep_time = sleep_time
 
     def captcha_handler(self, task_payload: Dict) -> Dict[str, Any]:
